Welcome to |project|'s documentation!
=====================================

.. include:: ../README.rst
   :end-before: DO-NOT-REMOVE-docs-badges-END

.. include:: ../README.rst
   :start-after: DO-NOT-REMOVE-docs-intro-START

.. toctree::
   :maxdepth: 2
   :caption: Go deeper:

   change-notes-layout
   contributing

.. toctree::
   :maxdepth: 2
   :caption: Private (Dev) API:

   pkg/modules


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
